| Title: | The Use of Marginal Distributions in Conditional Forecasting |
|---|---|
| Description: | A new way to predict time series using the marginal distribution table in the absence of the significance of traditional models. |
| Authors: | Mohamad-Taher Anan [aut], Mohamad Alawad [aut], Bushra Alsaeed [aut, cre] |
| Maintainer: | Bushra Alsaeed <[email protected]> |
| License: | GPL-3 |
| Version: | 0.1.1 |
| Built: | 2026-05-07 06:12:09 UTC |
| Source: | https://github.com/cran/MB |
A new way to predict time series using the marginal distribution table in the absence of the significance of traditional models.
ff(dt,m,w,n,q1)ff(dt,m,w,n,q1)
dt |
data frame |
m |
the number of time series |
w |
the number of predicted values |
n |
number of values |
q1 |
matrix independent time series values #In the case of m=2, enter the independent string values as follows(matrix(c())),In the case of m=3, enter the independent string values as follows(matrix(c(),w,m-1,byrow=T)) |
the output from ff()
x=rnorm(17,10,1) y=rnorm(17,10,1) data=data.frame(x,y) print("Enter independent time series values") q1=list(q=matrix(c(scan(,,quiet=TRUE)),1,2-1)) 10.5 ff(data,2,1,17,q1)x=rnorm(17,10,1) y=rnorm(17,10,1) data=data.frame(x,y) print("Enter independent time series values") q1=list(q=matrix(c(scan(,,quiet=TRUE)),1,2-1)) 10.5 ff(data,2,1,17,q1)