Welcome to ClientVPS Mirrors

Help for package MB
Type: Package
Title: The Use of Marginal Distributions in Conditional Forecasting
Version: 0.1.1
Author: Mohamad-Taher Anan [aut], Mohamad Alawad [aut], Bushra Alsaeed [aut, cre]
Maintainer: Bushra Alsaeed <alsaeedbushra41@gmail.com>
Description: A new way to predict time series using the marginal distribution table in the absence of the significance of traditional models.
License: GPL-3
Encoding: UTF-8
RoxygenNote: 7.2.1
Suggests: knitr, rmarkdown
VignetteBuilder: knitr
Imports: tibble
NeedsCompilation: no
Packaged: 2023-01-05 17:17:45 UTC; MB
Repository: CRAN
Date/Publication: 2023-01-06 21:30:06 UTC

The Use of Marginal Distributions in Conditional Forecasting

Description

A new way to predict time series using the marginal distribution table in the absence of the significance of traditional models.

Usage

ff(dt,m,w,n,q1)

Arguments

dt

data frame

m

the number of time series

w

the number of predicted values

n

number of values

q1

matrix independent time series values #In the case of m=2, enter the independent string values as follows(matrix(c())),In the case of m=3, enter the independent string values as follows(matrix(c(),w,m-1,byrow=T))

Value

the output from ff()

Examples

x=rnorm(17,10,1)
y=rnorm(17,10,1)
data=data.frame(x,y)
print("Enter independent time series values")
q1=list(q=matrix(c(scan(,,quiet=TRUE)),1,2-1))
10.5


ff(data,2,1,17,q1)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.